==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LinksQuestions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksQuestionsQuestion;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksQuestions
 */
@JsonPropertyOrder({ LinksQuestions.JSON_PROPERTY_QUESTION })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksQuestions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_QUESTION = "question";
    private LinksQuestionsQuestion question;

    public LinksQuestions() {
    }

    public LinksQuestions question(LinksQuestionsQuestion question) {

        this.question = question;
        return this;
    }

    /**
     * Get question
     *
     * @return question
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_QUESTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksQuestionsQuestion getQuestion() {
        return question;
    }

    @JsonProperty(JSON_PROPERTY_QUESTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setQuestion(LinksQuestionsQuestion question) {
        this.question = question;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksQuestions linksQuestions = (LinksQuestions) o;
        return Objects.equals(this.question, linksQuestions.question);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(question);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksQuestions {\n");
        sb.append("    question: ").append(toIndentedString(question)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/LinksQuestions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksQuestionsQuestion;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksQuestions
 */
@JsonPropertyOrder({ LinksQuestions.JSON_PROPERTY_QUESTION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksQuestions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_QUESTION = "question";
    private LinksQuestionsQuestion question;

    public LinksQuestions() {
    }

    public LinksQuestions question(LinksQuestionsQuestion question) {

        this.question = question;
        return this;
    }

    /**
     * Get question
     *
     * @return question
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_QUESTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksQuestionsQuestion getQuestion() {
        return question;
    }

    @JsonProperty(JSON_PROPERTY_QUESTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setQuestion(LinksQuestionsQuestion question) {
        this.question = question;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksQuestions linksQuestions = (LinksQuestions) o;
        return Objects.equals(this.question, linksQuestions.question);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(question);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksQuestions {\n");
        sb.append("    question: ").append(toIndentedString(question)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
